manhattan forms
===============

A set of classes, functions and utilties that extend WTForms for use with
manhattan.

How to install
--------------

`pip install manhattan_forms`

Testing
-------

`pip install --no-deps -e .`

`py.test`